pub struct BoundsChangedEvent {
pub item: ObjectRefOwned,
}Expand description
An event triggered when the visual bounds for an item have changed. This usually happens either:
- due to a re-draw on a window whose size has changed and dynamically adjusted said item’s visual size, or
- content within the bounds of said item has changed to change its size.
Fields
item: ObjectRefOwnedThe crate::ObjectRef which the event applies to.