pub struct TextBoundsChangedEvent {
pub item: ObjectRefOwned,
}Expand description
The bounds of a piece of text have changed.
This event does not specify what the new bounds are; it is only to notify an AT that the bounds have changed.
To query information about the new state of the selection, use atspi_proxies::TextProxy’s get_bounded_ranges function.
Fields
item: ObjectRefOwnedThe crate::ObjectRef which the event applies to.